@@ -37,8 +37,9 @@ class MysqlPool(BaseConnectionPool):
             raise NotImplementedError
 
     def sync_create_pool(self):
-        pool = PersistentDB(creator=pymysql, ping=2, closeable=True, maxusage=self.conn_info.max_size,
-                            host=self.conn_info.host, port=self.conn_info.port, user=self.conn_info.user,
-                            passwd=self.conn_info.password, db=self.conn_info.db_name, charset="utf8",
-                            autocommit=True)
+        pool = PooledDB(creator=pymysql, host=self.conn_info.host, port=self.conn_info.port, user=self.conn_info.user,
+                        passwd=self.conn_info.password, db=self.conn_info.db_name,
+                        mincached=self.conn_info.min_size, maxcached=self.conn_info.max_size,
+                        ping=1, maxconnections=self.conn_info.max_size, maxshared=self.conn_info.max_size,
+                        maxusage=self.conn_info.max_size, charset="utf8", autocommit=True)
         return pool
