@@ -9,6 +9,7 @@ import logging
 import tornado.web
 import tornado.ioloop
 import tornado.httpserver
+from apscheduler.schedulers.tornado import TornadoScheduler
 from tornado.log import LogFormatter as TornadoLogFormatter  # 避免命名歧义，设置了别名
 from tornado.options import options, define
 from typing import Optional
@@ -41,6 +42,8 @@ define("rms_register_server", default="http://127.0.0.1:8918", type=str, help="
 define("running_env", default="local", type=str, help="运行环境")
 define("db", default=SQLAlchemy(), type=SQLAlchemy, help="SqlAlchemy")
 define("ks3_connect_config", default={}, type=dict, help="金山对象存储连接配置")
+define("scheduler", default=None, type=TornadoScheduler, help="Tornado任务调度")
+define("scheduler_enable", default=False, type=bool, help="Tornado任务调度")
 # 日志初始化配置，配置文件中可修改设置
 options.logging = "DEBUG"
 options.log_rotate_mode = "time"
@@ -48,7 +51,7 @@ options.log_file_prefix = "log"
 options.log_rotate_when = "D"
 # options.log_rotate_interval,
 options.log_file_num_backups = 30
-options.async_enable = True
+options.async_enable = False
 options.eureka_enable = False
 options.eureka_server = ""
 options.eureka_instance_name = ""
@@ -122,6 +125,9 @@ class WebServer:
         # 5、自动化注册Handler处理类，
         self.autoRegisterHandler(f"{os.path.abspath(os.path.dirname(sys.argv[0]))}/{options.handler_path}",
                                  options.handler_path)
+        self.autoRegisterExtendHandler()
+        if options.scheduler_enable:
+            self.init_scheduler()
         self.app = tornado.web.Application(
             RouterMapping.instance(),
             cookie_secret=options.cookie_secret,
@@ -176,4 +182,27 @@ class WebServer:
                 self.autoRegisterHandler(os.path.join(path, handler_name), ".".join([pkg_name, handler_name]))
             elif os.path.isfile(full_file) and handler_name.lower().endswith("handler.py"):
                 # 文件，并且为handler结尾，认为是请求处理器，完成动态装载
+                ft = "{}.{}".format(pkg_name, handler_name.replace(".py", ""))
                 __import__("{}.{}".format(pkg_name, handler_name.replace(".py", "")))
+
+    def autoRegisterExtendHandler(self):
+        # 首先获取当前目录所有文件及文件夹
+        import lesscode
+        path = f"{os.path.abspath(os.path.dirname(lesscode.__file__))}/extend_handlers"
+        pkg_name = "lesscode.extend_handlers"
+        dynamic_handler_names = os.listdir(path)
+        for handler_name in dynamic_handler_names:
+            # 利用os.path.join()方法获取完整路径
+            full_file = os.path.join(path, handler_name)
+            # 循环判断每个元素是文件夹还是文件
+            if os.path.isdir(full_file):
+                # 文件夹递归遍历
+                self.autoRegisterHandler(os.path.join(path, handler_name), ".".join([pkg_name, handler_name]))
+            elif os.path.isfile(full_file) and handler_name.lower().endswith("handler.py"):
+                # 文件，并且为handler结尾，认为是请求处理器，完成动态装载
+                __import__("{}.{}".format(pkg_name, handler_name.replace(".py", "")))
+
+    def init_scheduler(self):
+        options.scheduler = TornadoScheduler()
+        options.scheduler.start()
+        logging.info('[Scheduler Init]APScheduler has been started')
